#!/usr/bin/env php
<?php
/**
 * GLPI CVE Plugin - CLI Inventory Analysis Script
 * This script can be called from cron to analyze software inventory
 */

// Define GLPI's constants
define('GLPI_ROOT', dirname(__FILE__, 4));

// Include necessary files
include(GLPI_ROOT . "/inc/autoload.function.php");
include(GLPI_ROOT . "/inc/db.function.php");
include_once(GLPI_ROOT . "/inc/includes.php");

// No time limit for potentially long-running operation
set_time_limit(0);

// Ensure CLI mode is used
if (PHP_SAPI != 'cli') {
   echo "This script must be run from command line";
   exit(1);
}

// Initialize GLPI
$DB = new DB();
Session::setPath();
Session::start();
Session::loadLanguage();

// Use GLPI's CLI mode
if (!Session::getLoginUserID()) {
   Session::setGlpiSessionPath();
   Session::setGlpiSessionID('cli_' . getmypid());
   $_SESSION['glpi_use_mode'] = Session::NORMAL_MODE;
   $_SESSION['glpiname'] = 'cli_cve_inventory';
   Session::loadGroups();
}

// Run the inventory analysis
$task = new CronTask();
if ($task->getFromDBbyName('PluginCveCveInventory', 'AnalyzeInventory')) {
   echo "Starting software vulnerability analysis...\n";
   
   $result = PluginCveCveInventory::cronAnalyzeInventory($task);
   
   if ($result) {
      echo "Software vulnerability analysis completed successfully.\n";
      exit(0);
   } else {
      echo "Software vulnerability analysis completed with no new alerts.\n";
      exit(0);
   }
} else {
   echo "Software vulnerability analysis task not found.\n";
   exit(1);
}