import React from 'react';
import { PieChart as ChartPie, ShieldAlert, Clock, FileText } from 'lucide-react';
import { mockCVEs } from '../data/mockData';

const severityColors = {
  CRITICAL: 'bg-red-500',
  HIGH: 'bg-orange-500',
  MEDIUM: 'bg-yellow-500',
  LOW: 'bg-blue-500'
};

const statusCounts = {
  NEW: mockCVEs.filter(cve => cve.status === 'NEW').length,
  ANALYZED: mockCVEs.filter(cve => cve.status === 'ANALYZED').length,
  ASSIGNED: mockCVEs.filter(cve => cve.status === 'ASSIGNED').length,
  RESOLVED: mockCVEs.filter(cve => cve.status === 'RESOLVED').length,
};

const severityCounts = {
  CRITICAL: mockCVEs.filter(cve => cve.severity === 'CRITICAL').length,
  HIGH: mockCVEs.filter(cve => cve.severity === 'HIGH').length,
  MEDIUM: mockCVEs.filter(cve => cve.severity === 'MEDIUM').length,
  LOW: mockCVEs.filter(cve => cve.severity === 'LOW').length,
};

const Dashboard = () => {
  return (
    <div className="p-6">
      <div className="mb-8">
        <h1 className="text-2xl font-bold mb-1">CVE Dashboard</h1>
        <p className="text-gray-600">Overview of vulnerability management status</p>
      </div>

      <div className="grid grid-cols-1 md:grid-cols-4 gap-6 mb-8">
        <div className="bg-white rounded-lg shadow p-6">
          <div className="flex items-center mb-4">
            <div className="rounded-full bg-red-100 p-3 mr-4">
              <ShieldAlert className="h-6 w-6 text-red-600" />
            </div>
            <div>
              <p className="text-gray-500 text-sm">Critical Vulnerabilities</p>
              <p className="text-2xl font-bold">{severityCounts.CRITICAL}</p>
            </div>
          </div>
          <div className="h-2 bg-gray-200 rounded-full overflow-hidden">
            <div className="bg-red-500 h-full" style={{ width: `${(severityCounts.CRITICAL / mockCVEs.length) * 100}%` }}></div>
          </div>
        </div>

        <div className="bg-white rounded-lg shadow p-6">
          <div className="flex items-center mb-4">
            <div className="rounded-full bg-orange-100 p-3 mr-4">
              <ShieldAlert className="h-6 w-6 text-orange-600" />
            </div>
            <div>
              <p className="text-gray-500 text-sm">High Risk Vulnerabilities</p>
              <p className="text-2xl font-bold">{severityCounts.HIGH}</p>
            </div>
          </div>
          <div className="h-2 bg-gray-200 rounded-full overflow-hidden">
            <div className="bg-orange-500 h-full" style={{ width: `${(severityCounts.HIGH / mockCVEs.length) * 100}%` }}></div>
          </div>
        </div>

        <div className="bg-white rounded-lg shadow p-6">
          <div className="flex items-center mb-4">
            <div className="rounded-full bg-blue-100 p-3 mr-4">
              <Clock className="h-6 w-6 text-blue-600" />
            </div>
            <div>
              <p className="text-gray-500 text-sm">Pending Analysis</p>
              <p className="text-2xl font-bold">{statusCounts.NEW}</p>
            </div>
          </div>
          <div className="h-2 bg-gray-200 rounded-full overflow-hidden">
            <div className="bg-blue-500 h-full" style={{ width: `${(statusCounts.NEW / mockCVEs.length) * 100}%` }}></div>
          </div>
        </div>

        <div className="bg-white rounded-lg shadow p-6">
          <div className="flex items-center mb-4">
            <div className="rounded-full bg-green-100 p-3 mr-4">
              <FileText className="h-6 w-6 text-green-600" />
            </div>
            <div>
              <p className="text-gray-500 text-sm">Resolved Issues</p>
              <p className="text-2xl font-bold">{statusCounts.RESOLVED}</p>
            </div>
          </div>
          <div className="h-2 bg-gray-200 rounded-full overflow-hidden">
            <div className="bg-green-500 h-full" style={{ width: `${(statusCounts.RESOLVED / mockCVEs.length) * 100}%` }}></div>
          </div>
        </div>
      </div>

      <div className="grid grid-cols-1 lg:grid-cols-3 gap-6">
        <div className="col-span-2 bg-white rounded-lg shadow">
          <div className="p-6 border-b border-gray-200">
            <h2 className="text-xl font-semibold">Recent Vulnerabilities</h2>
          </div>
          <div className="p-6">
            <div className="overflow-x-auto">
              <table className="min-w-full">
                <thead>
                  <tr className="bg-gray-50">
                    <th className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">CVE ID</th>
                    <th className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Severity</th>
                    <th className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">CVSS</th>
                    <th className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Published</th>
                    <th className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Status</th>
                  </tr>
                </thead>
                <tbody className="bg-white divide-y divide-gray-200">
                  {mockCVEs.slice(0, 5).map((cve) => (
                    <tr key={cve.id} className="hover:bg-gray-50">
                      <td className="px-6 py-4 whitespace-nowrap text-sm font-medium text-blue-600">{cve.cve_id}</td>
                      <td className="px-6 py-4 whitespace-nowrap">
                        <span className={`inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium ${
                          cve.severity === 'CRITICAL' ? 'bg-red-100 text-red-800' :
                          cve.severity === 'HIGH' ? 'bg-orange-100 text-orange-800' :
                          cve.severity === 'MEDIUM' ? 'bg-yellow-100 text-yellow-800' :
                          'bg-blue-100 text-blue-800'
                        }`}>
                          {cve.severity}
                        </span>
                      </td>
                      <td className="px-6 py-4 whitespace-nowrap text-sm text-gray-500">{cve.cvss_score.toFixed(1)}</td>
                      <td className="px-6 py-4 whitespace-nowrap text-sm text-gray-500">
                        {new Date(cve.published_date).toLocaleDateString()}
                      </td>
                      <td className="px-6 py-4 whitespace-nowrap">
                        <span className={`inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium ${
                          cve.status === 'NEW' ? 'bg-blue-100 text-blue-800' :
                          cve.status === 'ANALYZED' ? 'bg-yellow-100 text-yellow-800' :
                          cve.status === 'ASSIGNED' ? 'bg-purple-100 text-purple-800' :
                          'bg-green-100 text-green-800'
                        }`}>
                          {cve.status}
                        </span>
                      </td>
                    </tr>
                  ))}
                </tbody>
              </table>
            </div>
          </div>
        </div>

        <div className="bg-white rounded-lg shadow">
          <div className="p-6 border-b border-gray-200">
            <h2 className="text-xl font-semibold">Severity Distribution</h2>
          </div>
          <div className="p-6 flex flex-col items-center">
            <div className="w-full h-48 mb-4 flex items-end justify-around">
              {Object.entries(severityCounts).map(([severity, count]) => (
                <div key={severity} className="flex flex-col items-center">
                  <div
                    className={`${severityColors[severity as keyof typeof severityColors]} rounded-t-lg w-16`}
                    style={{ height: `${Math.max((count / mockCVEs.length) * 150, 20)}px` }}
                  ></div>
                  <div className="mt-2 text-xs font-medium">{severity}</div>
                  <div className="text-gray-600 font-semibold">{count}</div>
                </div>
              ))}
            </div>
            <div className="mt-4 text-gray-500 text-sm text-center">
              Total vulnerabilities: {mockCVEs.length}
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default Dashboard;