import { CVE, CVESource, CVERule } from '../types/cve';

export const mockCVEs: CVE[] = [
  {
    id: 1,
    cve_id: 'CVE-2024-1234',
    description: 'A remote code execution vulnerability in Apache Log4j library affecting versions 2.0-beta9 to 2.14.1',
    cvss_score: 10.0,
    cvss_vector: 'CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:C/C:H/I:H/A:H',
    severity: 'CRITICAL',
    published_date: '2024-05-12T00:00:00Z',
    modified_date: '2024-05-14T00:00:00Z',
    status: 'NEW',
    references: [
      'https://nvd.nist.gov/vuln/detail/CVE-2024-1234',
      'https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2024-1234'
    ],
    affected_products: ['Apache Log4j 2.0-2.14.1', 'Applications using affected Log4j versions'],
    date_creation: '2024-05-15T10:30:00Z',
    date_mod: '2024-05-15T10:30:00Z'
  },
  {
    id: 2,
    cve_id: 'CVE-2024-5678',
    description: 'SQL Injection vulnerability in WordPress plugin Contact Form 7 versions prior to 5.7.2',
    cvss_score: 8.8,
    cvss_vector: 'CVSS:3.1/AV:N/AC:L/PR:L/UI:N/S:U/C:H/I:H/A:H',
    severity: 'HIGH',
    published_date: '2024-05-10T00:00:00Z',
    modified_date: '2024-05-11T00:00:00Z',
    status: 'ANALYZED',
    references: [
      'https://nvd.nist.gov/vuln/detail/CVE-2024-5678',
      'https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2024-5678'
    ],
    affected_products: ['WordPress Contact Form 7 < 5.7.2'],
    date_creation: '2024-05-12T08:15:00Z',
    date_mod: '2024-05-12T14:25:00Z'
  },
  {
    id: 3,
    cve_id: 'CVE-2024-9012',
    description: 'Privilege escalation vulnerability in Microsoft Windows 11 affecting kernel-mode drivers',
    cvss_score: 7.8,
    cvss_vector: 'CVSS:3.1/AV:L/AC:L/PR:L/UI:N/S:U/C:H/I:H/A:H',
    severity: 'HIGH',
    published_date: '2024-05-08T00:00:00Z',
    modified_date: '2024-05-09T00:00:00Z',
    status: 'ASSIGNED',
    references: [
      'https://nvd.nist.gov/vuln/detail/CVE-2024-9012',
      'https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2024-9012'
    ],
    affected_products: ['Microsoft Windows 11 21H2', 'Microsoft Windows 11 22H2'],
    date_creation: '2024-05-10T09:45:00Z',
    date_mod: '2024-05-13T11:20:00Z'
  },
  {
    id: 4,
    cve_id: 'CVE-2024-3456',
    description: 'Cross-site scripting (XSS) vulnerability in jQuery UI Dialog component prior to version 1.13.2',
    cvss_score: 5.4,
    cvss_vector: 'CVSS:3.1/AV:N/AC:L/PR:N/UI:R/S:U/C:L/I:L/A:N',
    severity: 'MEDIUM',
    published_date: '2024-05-05T00:00:00Z',
    modified_date: '2024-05-06T00:00:00Z',
    status: 'RESOLVED',
    references: [
      'https://nvd.nist.gov/vuln/detail/CVE-2024-3456',
      'https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2024-3456'
    ],
    affected_products: ['jQuery UI < 1.13.2'],
    date_creation: '2024-05-07T14:30:00Z',
    date_mod: '2024-05-15T09:10:00Z'
  },
  {
    id: 5,
    cve_id: 'CVE-2024-7890',
    description: 'Information disclosure vulnerability in OpenSSL 3.0.0 through 3.1.1',
    cvss_score: 3.7,
    cvss_vector: 'CVSS:3.1/AV:N/AC:H/PR:N/UI:N/S:U/C:L/I:N/A:N',
    severity: 'LOW',
    published_date: '2024-05-02T00:00:00Z',
    modified_date: '2024-05-03T00:00:00Z',
    status: 'ANALYZED',
    references: [
      'https://nvd.nist.gov/vuln/detail/CVE-2024-7890',
      'https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2024-7890'
    ],
    affected_products: ['OpenSSL 3.0.0-3.1.1'],
    date_creation: '2024-05-04T16:45:00Z',
    date_mod: '2024-05-10T13:25:00Z'
  }
];

export const mockSources: CVESource[] = [
  {
    id: 1,
    name: 'National Vulnerability Database (NVD)',
    url: 'https://services.nvd.nist.gov/rest/json/cves/2.0',
    api_key: '********-****-****-****-************',
    source_type: 'NVD',
    data_format: 'JSON',
    is_active: true,
    sync_frequency: 4,
    last_sync: '2024-05-15T08:00:00Z',
    sync_status: 'SUCCESS'
  },
  {
    id: 2,
    name: 'MITRE CVE Database',
    url: 'https://cveawg.mitre.org/api/',
    api_key: '',
    source_type: 'MITRE',
    data_format: 'JSON',
    is_active: true,
    sync_frequency: 24,
    last_sync: '2024-05-14T22:00:00Z',
    sync_status: 'SUCCESS'
  },
  {
    id: 3,
    name: 'CISA KEV Catalog',
    url: 'https://www.cisa.gov/sites/default/files/feeds/known_exploited_vulnerabilities.json',
    api_key: '',
    source_type: 'CISA',
    data_format: 'JSON',
    is_active: true,
    sync_frequency: 12,
    last_sync: '2024-05-15T04:00:00Z',
    sync_status: 'SUCCESS'
  }
];

export const mockRules: CVERule[] = [
  {
    id: 1,
    name: 'Critical Vulnerabilities - Immediate Ticket',
    criteria: {
      severity: 'CRITICAL',
      affected_systems: { min: 1 }
    },
    actions: {
      create_ticket: true,
      ticket_priority: 'VERY HIGH',
      notify_admins: true
    },
    priority: 1,
    is_active: true
  },
  {
    id: 2,
    name: 'High Risk - Production Systems',
    criteria: {
      severity: 'HIGH',
      system_tags: ['production', 'customer-facing']
    },
    actions: {
      create_ticket: true,
      ticket_priority: 'HIGH',
      notify_admins: false
    },
    priority: 2,
    is_active: true
  },
  {
    id: 3,
    name: 'Medium Risk - Batch Report',
    criteria: {
      severity: 'MEDIUM',
      system_count: { min: 1 }
    },
    actions: {
      create_ticket: false,
      add_to_report: true,
      schedule_report: 'WEEKLY'
    },
    priority: 3,
    is_active: true
  }
];